package com.example.autorization.ui.fragments.signup

import android.os.Bundle
import android.text.InputType
import androidx.fragment.app.Fragment
import android.view.MotionEvent
import android.view.View
import android.widget.Button
import android.widget.CheckBox
import android.widget.EditText
import android.widget.TextView
import android.widget.Toast
import androidx.core.widget.doOnTextChanged
import androidx.fragment.app.activityViewModels
import androidx.fragment.app.commit
import androidx.fragment.app.replace
import androidx.fragment.app.viewModels
import com.example.autorization.R
import com.example.autorization.ui.fragments.users.UserViewModel
import com.example.autorization.ui.fragments.users.UsersFragment

class SignUpScreen : Fragment(R.layout.fragment_sign_up_screen) {
    
    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        val viewModel by viewModels<SignUpViewModel> ()

        val viewModelUser by activityViewModels<UserViewModel> ()



        val passwordEditText =  view.findViewById<EditText>(R.id.PasswordEditText)
        val loginEditText =  view.findViewById<EditText>(R.id.EmailPhoneNumberEditText)
        val nameEditText =  view.findViewById<EditText>(R.id.NameEditText)
        val termsCheckBox = view.findViewById<CheckBox>(R.id.TarmsAndPolicyCheckBox)
        val createButton = view.findViewById<Button>(R.id.CreateAccountButton)
        val errorTextView = view.findViewById<TextView>(R.id.ErrorLabel)
        var passwordIsVisible = false

        passwordEditText.doOnTextChanged { text, _, _, _ ->
            viewModel.setPassword(text.toString())
        }
        loginEditText.doOnTextChanged { text, _, _, _ ->
            viewModel.setLogin(text.toString())
        }
        nameEditText.doOnTextChanged { text, _, _, _ ->
            viewModel.setName(text.toString())
        }

        createButton.setOnClickListener {
            val user = viewModel.registrationUser()
            if(user != null) {
                viewModelUser.addUser(user)
                parentFragmentManager.commit {
                    replace<UsersFragment>(R.id.fragment_container_view)
                }
            }
        }

        viewModel.signUpState.observeForever{
            createButton.isEnabled = it.acceptTerms
            if(it.errorMessage.isNotBlank()) {
                errorTextView.text = it.errorMessage
                errorTextView.visibility = View.VISIBLE
            }
        }

        termsCheckBox.setOnCheckedChangeListener { buttonView, isChecked ->
            viewModel.changeTerms(isChecked)
        }




        passwordEditText.setOnTouchListener { v, event ->
            if(event.action == MotionEvent.ACTION_UP){
                if(event.rawX >= passwordEditText.right -
                    passwordEditText.compoundDrawables[2].bounds.width()
                    - passwordEditText.paddingEnd){
                   passwordIsVisible = !passwordIsVisible
                    if(passwordIsVisible){
                        passwordEditText.inputType = InputType.TYPE_CLASS_TEXT or
                        InputType.TYPE_TEXT_VARIATION_VISIBLE_PASSWORD
                    }else{
                        passwordEditText.inputType = InputType.TYPE_CLASS_TEXT or
                                InputType.TYPE_TEXT_VARIATION_PASSWORD
                    }
                }
            }
            false
        }

    }

}